@@ -15,10 +15,13 @@
 
 import re
 import blockdiag.elements
-from blockdiag.elements import DiagramEdge, NodeGroup
 from blockdiag.utils import images, unquote
 
 
+class NodeGroup(blockdiag.elements.NodeGroup):
+    pass
+
+
 class DiagramNode(blockdiag.elements.DiagramNode):
     def __init__(self, _id):
         super(DiagramNode, self).__init__(_id)
@@ -39,6 +42,10 @@ class DiagramNode(blockdiag.elements.DiagramNode):
                 self.set_attribute(attr)
 
 
+class DiagramEdge(blockdiag.elements.DiagramEdge):
+    pass
+
+
 class Network(blockdiag.elements.NodeGroup):
     basecolor = (185, 203, 228)
     linecolor = (0, 0, 0)
