@@ -1,44 +1,35 @@
 # -*- coding: utf-8 -*-
 
+import sys
+if sys.version_info < (2, 7):
+    import unittest2 as unittest
+else:
+    import unittest
+
 import os
+import io
 import tempfile
-import unittest2
-from blockdiag.tests.utils import stderr_wrapper, assertRaises
+from blockdiag.tests.utils import stderr_wrapper, with_pil
 from docutils import nodes
 from docutils.core import publish_doctree, publish_parts
 from docutils.parsers.rst import directives as docutils
 from nwdiag.utils.rst import directives
 
 
-def setup_directive_base(func):
-    def _(self):
-        klass = directives.NwdiagDirectiveBase
-        docutils.register_directive('nwdiag', klass)
-        func(self)
+class TestRstDirectives(unittest.TestCase):
+    def setUp(self):
+        docutils.register_directive('nwdiag',
+                                    directives.NwdiagDirectiveBase)
+        self.tmpdir = tempfile.mkdtemp()
 
-    _.__name__ = func.__name__
-    return _
-
-
-def use_tmpdir(func):
-    def _(self):
-        try:
-            tmpdir = tempfile.mkdtemp()
-            func(self, tmpdir)
-        finally:
-            for file in os.listdir(tmpdir):
-                os.unlink(tmpdir + "/" + file)
-            os.rmdir(tmpdir)
-
-    _.__name__ = func.__name__
-    return _
-
-
-class TestRstDirectives(unittest2.TestCase):
     def tearDown(self):
         if 'nwdiag' in docutils._directives:
             del docutils._directives['nwdiag']
 
+        for file in os.listdir(self.tmpdir):
+            os.unlink(self.tmpdir + "/" + file)
+        os.rmdir(self.tmpdir)
+
     def test_setup(self):
         directives.setup()
         options = directives.directive_options
@@ -52,12 +43,10 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual(False, options['nodoctype'])
         self.assertEqual(False, options['noviewbox'])
         self.assertEqual(False, options['inline_svg'])
-        self.assertEqual(False, options['ignore_pil'])
 
     def test_setup_with_args(self):
         directives.setup(format='SVG', antialias=True, fontpath='/dev/null',
-                         nodoctype=True, noviewbox=True, inline_svg=True,
-                         ignore_pil=True)
+                         nodoctype=True, noviewbox=True, inline_svg=True)
         options = directives.directive_options
 
         self.assertIn('nwdiag', docutils._directives)
@@ -69,17 +58,14 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual(True, options['nodoctype'])
         self.assertEqual(True, options['noviewbox'])
         self.assertEqual(True, options['inline_svg'])
-        self.assertEqual(True, options['ignore_pil'])
 
     @stderr_wrapper
-    @setup_directive_base
     def test_base_noargs(self):
         text = ".. nwdiag::"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
         self.assertEqual(nodes.system_message, type(doctree[0]))
 
-    @setup_directive_base
     def test_base_with_block(self):
         text = ".. nwdiag::\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
@@ -90,14 +76,12 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual({}, doctree[0]['options'])
 
     @stderr_wrapper
-    @setup_directive_base
     def test_base_with_emptyblock(self):
         text = ".. nwdiag::\n\n   \n"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
         self.assertEqual(nodes.system_message, type(doctree[0]))
 
-    @setup_directive_base
     def test_base_with_filename(self):
         dirname = os.path.dirname(__file__)
         filename = os.path.join(dirname, 'diagrams/single_network.diag')
@@ -106,26 +90,23 @@ class TestRstDirectives(unittest2.TestCase):
 
         self.assertEqual(1, len(doctree))
         self.assertEqual(directives.nwdiag, type(doctree[0]))
-        self.assertEqual(open(filename).read(), doctree[0]['code'])
+        self.assertEqual(io.open(filename).read(), doctree[0]['code'])
         self.assertEqual(None, doctree[0]['alt'])
         self.assertEqual({}, doctree[0]['options'])
 
     @stderr_wrapper
-    @setup_directive_base
     def test_base_with_filename_not_exists(self):
         text = ".. nwdiag:: unknown.diag"
         doctree = publish_doctree(text)
         self.assertEqual(nodes.system_message, type(doctree[0]))
 
     @stderr_wrapper
-    @setup_directive_base
     def test_base_with_block_and_filename(self):
         text = ".. nwdiag:: unknown.diag\n\n   { A -> B }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
         self.assertEqual(nodes.system_message, type(doctree[0]))
 
-    @setup_directive_base
     def test_base_with_options(self):
         text = ".. nwdiag::\n   :alt: hello world\n   :desctable:\n" + \
                "   :maxwidth: 100\n\n   { network { A; B } }"
@@ -137,47 +118,44 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual(None, doctree[0]['options']['desctable'])
         self.assertEqual(100, doctree[0]['options']['maxwidth'])
 
-    @use_tmpdir
-    def test_block(self, path):
-        directives.setup(format='SVG', outputdir=path)
+    def test_block(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir)
         text = ".. nwdiag::\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
         self.assertEqual(nodes.image, type(doctree[0]))
         self.assertFalse('alt' in doctree[0])
-        self.assertEqual(0, doctree[0]['uri'].index(path))
+        self.assertEqual(0, doctree[0]['uri'].index(self.tmpdir))
         self.assertFalse('target' in doctree[0])
 
-    @use_tmpdir
-    def test_block_alt(self, path):
-        directives.setup(format='SVG', outputdir=path)
+    def test_block_alt(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir)
         text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
         self.assertEqual(nodes.image, type(doctree[0]))
         self.assertEqual('hello world', doctree[0]['alt'])
-        self.assertEqual(0, doctree[0]['uri'].index(path))
+        self.assertEqual(0, doctree[0]['uri'].index(self.tmpdir))
         self.assertFalse('target' in doctree[0])
 
-    @use_tmpdir
-    @assertRaises(RuntimeError)
-    def test_block_fontpath1(self, path):
-        directives.setup(format='SVG', fontpath=['dummy.ttf'],
-                         outputdir=path)
-        text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
-        publish_doctree(text)
+    def test_block_fontpath1(self):
+        with self.assertRaises(RuntimeError):
+            directives.setup(format='SVG', fontpath=['dummy.ttf'],
+                             outputdir=self.tmpdir)
+            text = ".. nwdiag::\n   :alt: hello world\n\n" + \
+                   "   { network { A; B } }"
+            publish_doctree(text)
 
-    @use_tmpdir
-    @assertRaises(RuntimeError)
-    def test_block_fontpath2(self, path):
-        directives.setup(format='SVG', fontpath='dummy.ttf',
-                         outputdir=path)
-        text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
-        publish_doctree(text)
+    def test_block_fontpath2(self):
+        with self.assertRaises(RuntimeError):
+            directives.setup(format='SVG', fontpath='dummy.ttf',
+                             outputdir=self.tmpdir)
+            text = ".. nwdiag::\n   :alt: hello world\n\n" + \
+                   "   { network { A; B } }"
+            publish_doctree(text)
 
-    @use_tmpdir
-    def test_caption(self, path):
-        directives.setup(format='SVG', outputdir=path)
+    def test_caption(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir)
         text = ".. nwdiag::\n   :caption: hello world\n\n" + \
                "   { network { A; B } }"
         doctree = publish_doctree(text)
@@ -190,20 +168,18 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual(nodes.Text, type(doctree[0][1][0]))
         self.assertEqual('hello world', doctree[0][1][0])
 
-    @use_tmpdir
-    def test_block_maxwidth(self, path):
-        directives.setup(format='SVG', outputdir=path)
+    def test_block_maxwidth(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir)
         text = ".. nwdiag::\n   :maxwidth: 100\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
         self.assertEqual(nodes.image, type(doctree[0]))
         self.assertFalse('alt' in doctree[0])
-        self.assertEqual(0, doctree[0]['uri'].index(path))
-        self.assertFalse(0, doctree[0]['target'].index(path))
+        self.assertEqual(0, doctree[0]['uri'].index(self.tmpdir))
+        self.assertFalse(0, doctree[0]['target'].index(self.tmpdir))
 
-    @use_tmpdir
-    def test_block_nodoctype_false(self, path):
-        directives.setup(format='SVG', outputdir=path, nodoctype=False)
+    def test_block_nodoctype_false(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir, nodoctype=False)
         text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
@@ -212,9 +188,8 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual("<?xml version='1.0' encoding='UTF-8'?>\n"
                          "<!DOCTYPE ", svg[:49])
 
-    @use_tmpdir
-    def test_block_nodoctype_true(self, path):
-        directives.setup(format='SVG', outputdir=path, nodoctype=True)
+    def test_block_nodoctype_true(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir, nodoctype=True)
         text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
@@ -223,9 +198,8 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertNotEqual("<?xml version='1.0' encoding='UTF-8'?>\n"
                             "<!DOCTYPE ", svg[:49])
 
-    @use_tmpdir
-    def test_block_noviewbox_false(self, path):
-        directives.setup(format='SVG', outputdir=path, noviewbox=False)
+    def test_block_noviewbox_false(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir, noviewbox=False)
         text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
@@ -233,9 +207,8 @@ class TestRstDirectives(unittest2.TestCase):
         svg = open(doctree[0]['uri']).read()
         self.assertRegexpMatches(svg, '<svg viewBox="0 0 \d+ \d+" ')
 
-    @use_tmpdir
-    def test_block_noviewbox_true(self, path):
-        directives.setup(format='SVG', outputdir=path, noviewbox=True)
+    def test_block_noviewbox_true(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir, noviewbox=True)
         text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
@@ -243,18 +216,16 @@ class TestRstDirectives(unittest2.TestCase):
         svg = open(doctree[0]['uri']).read()
         self.assertRegexpMatches(svg, '<svg height="\d+" width="\d+" ')
 
-    @use_tmpdir
-    def test_block_inline_svg_false(self, path):
-        directives.setup(format='SVG', outputdir=path, inline_svg=False)
+    def test_block_inline_svg_false(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir, inline_svg=False)
         text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
         self.assertEqual(nodes.image, type(doctree[0]))
-        self.assertEqual(1, len(os.listdir(path)))
+        self.assertEqual(1, len(os.listdir(self.tmpdir)))
 
-    @use_tmpdir
-    def test_block_inline_svg_true(self, path):
-        directives.setup(format='SVG', outputdir=path, inline_svg=True)
+    def test_block_inline_svg_true(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir, inline_svg=True)
         text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
@@ -263,26 +234,23 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual(nodes.Text, type(doctree[0][0]))
         self.assertEqual("<?xml version='1.0' encoding='UTF-8'?>\n"
                          "<!DOCTYPE ", doctree[0][0][:49])
-        self.assertEqual(0, len(os.listdir(path)))
+        self.assertEqual(0, len(os.listdir(self.tmpdir)))
 
-    @use_tmpdir
-    def test_block_inline_svg_true_but_nonsvg_format(self, path):
-        directives.setup(format='PNG', outputdir=path, inline_svg=True)
+    @with_pil
+    def test_block_inline_svg_true_but_nonsvg_format(self):
+        directives.setup(format='PNG', outputdir=self.tmpdir, inline_svg=True)
         text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
         self.assertEqual(nodes.image, type(doctree[0]))
 
-    @use_tmpdir
-    def test_block_inline_svg_true_with_multibytes(self, path):
-        directives.setup(format='SVG', outputdir=path,
-                         inline_svg=True, ignore_pil=True)
+    def test_block_inline_svg_true_with_multibytes(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir, inline_svg=True)
         text = ".. nwdiag::\n   :alt: hello world\n\n   { network { あ; い } }"
         publish_parts(text)
 
-    @use_tmpdir
-    def test_block_max_width_inline_svg(self, path):
-        directives.setup(format='SVG', outputdir=path,
+    def test_block_max_width_inline_svg(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir,
                          nodoctype=True, noviewbox=True, inline_svg=True)
         text = ".. nwdiag::\n   :maxwidth: 100\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
@@ -292,41 +260,15 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertRegexpMatches(doctree[0][0],
                                  '<svg height="\d+" width="100" ')
 
-    @use_tmpdir
-    def test_block_ignore_pil_false(self, path):
-        directives.setup(format='SVG', outputdir=path, ignore_pil=False)
-        text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
-        doctree = publish_doctree(text)
-        self.assertEqual(1, len(doctree))
-        self.assertEqual(nodes.image, type(doctree[0]))
-
-    @use_tmpdir
-    def test_block_ignore_pil_true(self, path):
-        directives.setup(format='SVG', outputdir=path, ignore_pil=True)
-        text = ".. nwdiag::\n   :alt: hello world\n\n   { network { A; B } }"
-        doctree = publish_doctree(text)
-        self.assertEqual(1, len(doctree))
-        self.assertEqual(nodes.image, type(doctree[-1]))
-
-    @use_tmpdir
-    def test_desctable_without_description(self, path):
-        directives.setup(format='SVG', outputdir=path)
+    def test_desctable_without_description(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir)
         text = ".. nwdiag::\n   :desctable:\n\n   { network { A; B } }"
         doctree = publish_doctree(text)
         self.assertEqual(1, len(doctree))
         self.assertEqual(nodes.image, type(doctree[0]))
 
-    @use_tmpdir
-    def test_desctable_without_description(self, path):
-        directives.setup(format='SVG', outputdir=path)
-        text = ".. nwdiag::\n   :desctable:\n\n   { network { A; B } }"
-        doctree = publish_doctree(text)
-        self.assertEqual(1, len(doctree))
-        self.assertEqual(nodes.image, type(doctree[0]))
-
-    @use_tmpdir
-    def test_desctable(self, path):
-        directives.setup(format='SVG', outputdir=path)
+    def test_desctable(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir)
         text = ".. nwdiag::\n   :desctable:\n\n" + \
                "   { network { A [description = foo];" + \
                "     B [description = bar]; } }"
@@ -360,9 +302,8 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual('B', tbody[1][0][0][0])
         self.assertEqual('bar', tbody[1][1][0][0])
 
-    @use_tmpdir
-    def test_desctable_using_node_group(self, path):
-        directives.setup(format='SVG', outputdir=path)
+    def test_desctable_using_node_group(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir)
         text = ".. nwdiag::\n   :desctable:\n\n" + \
                "   { network { A [description = foo];" + \
                "     B [description = bar]; } " + \
@@ -420,9 +361,8 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual(1, len(tbody[1][1]))
         self.assertEqual('bar', tbody[1][1][0][0])
 
-    @use_tmpdir
-    def test_desctable_with_rest_markups(self, path):
-        directives.setup(format='SVG', outputdir=path)
+    def test_desctable_with_rest_markups(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir)
         text = ".. nwdiag::\n   :desctable:\n\n" + \
                "   { network { A [description = \"foo *bar* **baz**\"]; " + \
                "     B [description = \"**foo** *bar* baz\"]; } }"
@@ -477,9 +417,8 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual(nodes.Text, type(tbody[1][1][0][3]))
         self.assertEqual(' baz', str(tbody[1][1][0][3]))
 
-    @use_tmpdir
-    def test_desctable_with_numbered(self, path):
-        directives.setup(format='SVG', outputdir=path)
+    def test_desctable_with_numbered(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir)
         text = ".. nwdiag::\n   :desctable:\n\n" + \
                "   { network { A [numbered = 2]; B [numbered = 1]; } }"
         doctree = publish_doctree(text)
@@ -512,9 +451,8 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual('2', tbody[1][0][0][0])
         self.assertEqual('A', tbody[1][1][0][0])
 
-    @use_tmpdir
-    def test_desctable_with_numbered_and_description(self, path):
-        directives.setup(format='SVG', outputdir=path)
+    def test_desctable_with_numbered_and_description(self):
+        directives.setup(format='SVG', outputdir=self.tmpdir)
         text = ".. nwdiag::\n   :desctable:\n\n" + \
                "   { network { A [description = foo, numbered = 2]; " + \
                "     B [description = bar, numbered = 1]; } }"
