@@ -55,7 +55,7 @@ class NwdiagDirective(directives.BlockdiagDirective):
     def node2image(self, node, diagram):
         options = node['options']
         filename = self.image_filename(node)
-        fontpath = self.detectfont()
+        fontmap = self.create_fontmap()
         _format = self.global_options['format'].lower()
 
         if _format == 'svg' and self.global_options['inline_svg'] is True:
@@ -63,7 +63,8 @@ class NwdiagDirective(directives.BlockdiagDirective):
 
         kwargs = dict(self.global_options)
         del kwargs['format']
-        drawer = DiagramDraw(_format, diagram, filename, **kwargs)
+        drawer = DiagramDraw(_format, diagram, filename,
+                             fontmap=fontmap, **kwargs)
 
         if filename is None or not os.path.isfile(filename):
             drawer.draw()
@@ -76,7 +77,7 @@ class NwdiagDirective(directives.BlockdiagDirective):
                     new_size = (options['maxwidth'], int(size[1] * ratio))
                     content = drawer.save(new_size)
 
-                return nodes.raw('', content.decode('utf-8'), format='html')
+                return nodes.raw('', content, format='html')
 
         size = drawer.pagesize()
         if 'maxwidth' in options and options['maxwidth'] < size[0]:
