@@ -13,6 +13,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+import sys
 import rackdiag
 import rackdiag.builder
 import rackdiag.drawer
@@ -24,5 +25,5 @@ class RackdiagApp(Application):
     module = rackdiag
 
 
-def main():
-    return RackdiagApp().run()
+def main(args=sys.argv[1:]):
+    return RackdiagApp().run(args)
