@@ -13,11 +13,16 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import division
 import re
 import blockdiag.elements
 from rackdiag.utils.math import lcm
-from blockdiag.elements import DiagramNode
 from blockdiag.utils import XY
+from blockdiag.utils.compat import u
+
+
+class DiagramNode(blockdiag.elements.DiagramNode):
+    pass
 
 
 class RackItem(blockdiag.elements.DiagramNode):
@@ -47,19 +52,19 @@ class RackItem(blockdiag.elements.DiagramNode):
     def display_label(self):
         attrs = []
         if self.colheight > 1:
-            attrs.append(u"%dU" % self.colheight)
+            attrs.append(u("%dU") % self.colheight)
         if self.ampere:
-            attrs.append(u"%.1fA" % self.ampere)
+            attrs.append(u("%.1fA") % self.ampere)
         if self.weight:
-            attrs.append(u"%.1fkg" % self.weight)
+            attrs.append(u("%.1fkg") % self.weight)
 
         labels = []
         if self.label:
             labels.append(self.label)
         if attrs:
-            labels.append(u"[%s]" % u"/".join(attrs))
+            labels.append(u("[%s]") % u("/").join(attrs))
 
-        return u"\n".join(labels)
+        return u("\n").join(labels)
 
     def set_attribute(self, attr):
         if re.search('^\d+U$', attr.name):
@@ -78,21 +83,21 @@ class RackItem(blockdiag.elements.DiagramNode):
         attrs = []
         for name in self.desctable:
             if name == 'units':
-                attrs.append(u"%dU" % self.colheight)
+                attrs.append(u("%dU") % self.colheight)
             elif name == 'ampere':
                 if self.ampere is None:
-                    attrs.append(u"")
+                    attrs.append(u(""))
                 else:
-                    attrs.append((u"%.1fA" % self.ampere) or u"")
+                    attrs.append((u("%.1fA") % self.ampere) or u(""))
             elif name == 'weight':
                 if self.weight is None:
-                    attrs.append(u"")
+                    attrs.append(u(""))
                 else:
-                    attrs.append((u"%.1fkg" % self.weight) or u"")
+                    attrs.append((u("%.1fkg") % self.weight) or u(""))
             else:
                 value = getattr(self, name)
                 if value is None:
-                    attrs.append(u"")
+                    attrs.append(u(""))
                 elif isinstance(value, int):
                     attrs.append(str(value))
                 else:
@@ -115,15 +120,15 @@ class Rack(blockdiag.elements.NodeGroup):
     def display_label(self):
         attrs = []
         if self.description or attrs:
-            attrs.insert(0, u"%dU" % self.colheight)
+            attrs.insert(0, u("%dU") % self.colheight)
 
         labels = []
         if self.description:
             labels.append(self.description)
         if attrs:
-            labels.append(u"[%s]" % u"/".join(attrs))
+            labels.append(u("[%s]") % u("/").join(attrs))
 
-        return u"\n".join(labels)
+        return u("\n").join(labels)
 
     def items(self, levels):
         if isinstance(levels, int):
@@ -175,7 +180,7 @@ class Rack(blockdiag.elements.NodeGroup):
                 for level in levels:
                     nodes = self.items(level)
                     if nodes:
-                        width = self.colwidth / colwidth
+                        width = self.colwidth // colwidth
                         for node in nodes:
                             node.xy = XY(node.xy.x * width, node.xy.y)
                             node.colwidth = width
